@@ -527,7 +527,7 @@ sub import_key {
   elsif ($data =~ /^\s*(\{.*?\})\s*$/s) {
     # JSON Web Key (JWK) - http://tools.ietf.org/html/draft-ietf-jose-json-web-key
     my $json = "$1";
-    my $h = eval { _decode_json($json) };
+    my $h = _decode_json($json);
     if ($h && $h->{kty} eq "EC") {
       for (qw/x y d/) {
         $h->{$_} = eval { unpack("H*", _decode_base64url($h->{$_})) } if exists $h->{$_};
@@ -985,6 +985,8 @@ See L<http://tools.ietf.org/html/draft-ietf-jose-json-web-key>
   "d":"870MB6gfuTJ4HtUnUvYMyJpr5eUZNP4Bk43bVdj3eAE",
  }
 
+B<BEWARE:> For JWK support you need to have L<JSON::PP>, L<JSON::XS> or L<Cpanel::JSON::XS> module.
+
 =item * EC public keys in JSON Web Key (JWK) format
 
  {
@@ -994,6 +996,8 @@ See L<http://tools.ietf.org/html/draft-ietf-jose-json-web-key>
   "y":"4Etl6SRW2YiLUrN5vfvVHuhp7x8PxltmWWlbbM4IFyM",
  }
 
+B<BEWARE:> For JWK support you need to have L<JSON::PP>, L<JSON::XS> or L<Cpanel::JSON::XS> module.
+
 =back
 
 =head2 import_key_raw
@@ -1046,6 +1050,8 @@ Also exports public/private keys as a perl HASH with JWK structure.
  #or
  my $jwk_hash = $pk->export_key_jwk('public', 1);
 
+B<BEWARE:> For JWK support you need to have L<JSON::PP>, L<JSON::XS> or L<Cpanel::JSON::XS> module.
+
 =head2 export_key_raw
 
 Export raw public/private key. Public key is exported in ANS X9.63 format (compressed or uncompressed),
